@@ -1,5 +1,6 @@
 #' Highlight index case at 40 Broad Street.
 #'
+#' @param latlong Logical.
 #' @param cex Numeric. Size of point.
 #' @param col Character. Color of point.
 #' @param pch Numeric. Type of of point.
@@ -11,15 +12,16 @@
 #' segmentLocator("216-1")
 #' addIndexCase()
 
-addIndexCase <- function(cex = 2, col = "red", pch = 1, add.label = FALSE,
-  text.size = 0.5) {
+addIndexCase <- function(latlong = FALSE, cex = 2, col = "red", pch = 1,
+  add.label = FALSE, text.size = 0.5) {
 
-  index.case <- cholera::fatalities[cholera::fatalities$case == 32, ]
+  if (latlong) vars <- c("lon", "lat")
+  else vars <- c("x", "y")
+
+  index.case <- cholera::fatalities[cholera::fatalities$case == 32, vars]
+  points(index.case[, vars], col = col, cex = cex, pch = pch)
 
   if (add.label) {
-    text(index.case$x, index.case$y, labels = "40 Broad\nStreet",
-      cex = text.size)
+    text(index.case[, vars], labels = "40 Broad\nStreet", cex = text.size)
   }
-
-  points(index.case$x, index.case$y, col = col, cex = cex, pch = pch)
 }
