@@ -6,7 +6,7 @@
 #' @param dev.mode Logical. Development mode uses parallel::parLapply().
 #' @noRd
 
-isoVertices <- function(post = 50, post.type = "distance", multi.core = TRUE,
+isoVertices <- function(post = 50, post.type = "distance", multi.core = FALSE,
   dev.mode = FALSE) {
 
   cores <- multiCore(multi.core)
@@ -42,7 +42,7 @@ iso_vertices <- function(i, isobands, pump.dist, ortho.dist, diag.dist) {
   d <- c(stats::dist(cholera::regular.cases[vertices, ]))
   d <- stats::setNames(as.data.frame(d), "d")
   idx <- index0(vertices)
-  distance <- data.frame(v1 = vertices[idx$V1], v2 = vertices[idx$V2],
+  distance <- data.frame(v1 = vertices[idx$v1], v2 = vertices[idx$v2],
     d = signif(d), stringsAsFactors = FALSE)
 
   adjacency <- distance[distance$d == ortho.dist | distance$d == diag.dist, ]
@@ -138,7 +138,7 @@ plot.iso <- function(x, selected.post = "all", palette = "plasma",
 #' @param x An object of class "iso" created by \code{isoVertices()}.
 #' @param ... Additional arguments.
 #' @return A vector with observed counts.
-#' @export
+#' @noRd
 
 print.iso <- function(x, ...) {
   print(vapply(x$vertices, length, numeric(1L)))
